function outbits = sidmixsidplay(inbits,idx,targetbits)
  triangle = inbits(:,:,1,:); %already adjusted
  sawtooth = inbits(:,:,2,:);
  pulse = inbits(:,:,3,:);
  noise = inbits(:,:,4,:);

  configtable = ...
  {  ...
    %kevtris chip G (6581 R2)
    [     
        0.90251, 0.0,       0.,        1.9147,    1.6747,  0.62376 ; % error  1689 (280)
        0.93088, 2.4843,    0.0,       1.0353,    1.1484,  0.0      ; % error  6128 (130)
        0.90988, 2.26303,   1.13126,   1.0035,    1.13801, 0.0      ; % error 14243 (632)
        0.91,    1.192,     0.0,       1.0169,    1.2,     0.637    % error    64   (2)
    ],
    %kevtris chip V (8580 R5)
    [
        0.9632,   0.0,      0.975,    1.7467,    2.36132, 0.975395; % error  1380 (169)
        0.92886,  1.67696,  0.0,      1.1014,    1.4352,  0.0      ; % error  8007 (218)
        0.94043,  1.7937,   0.981,    1.1213,    1.4259,  0.0      ; % error 11957 (362)
        0.96211,  0.98695,  1.00387,  1.46499,   1.98375, 0.77777  % error  2369  (89)
    ]
  };
  
  settings = configtable{2};

  idx2 = idx;
  idx = false(1,4);
  idx(idx2) = true;
  if idx == [1 1 0 0]
    row = 1;
  elseif idx == [1 0 1 0]
    row = 2;
  elseif idx == [0 1 1 0]
    row = 3;
  elseif idx == [1 1 1 0]
    row = 4;
  end
 
  bias = settings(row,1);  
  pulsestrength = settings(row,2);
  topbit = settings(row,3);
  distance1 = settings(row,4);
  distance2 = settings(row,5);
  stmix = settings(row,6);

  outbits = zeros(size(targetbits));
  
  for i=1:size(inbits,1)
    o = sawtooth(i,:,:,:);

    %convert to Triangle
    if idx(1) && ~idx(2) 
        o = triangle(i,:,:,:);
    %or to Saw+Triangle
    elseif idx(1) && idx(2)
        % bottom bit is grounded via T waveform selector
        o(0+1) = o(0+1)*stmix;

        for j = 2:12
             %Enabling the S waveform pulls the XOR circuit selector transistor down
             %(which would normally make the descending ramp of the triangle waveform),
             %so ST does not actually have a sawtooth and triangle waveform combined,
             %but merely combines two sawtooths, one rising double the speed the other.
             %http://www.lemon64.com/forum/viewtopic.php?t=25442&postdays=0&postorder=asc&start=165
            o(j) = o(j - 1) * (1.0 - stmix) + o(j) * stmix;
        end
    end

    %topbit for Saw
    if idx(2)
        o(12) *= topbit;
    end

    %ST, P* waveforms
    if (idx(1)&&idx(2)) || idx(3) || idx(4)
        distancetable = nan(25,1);
        distancetable(13) = 1;
        for j=1:12
            distancetable(13-j) = 1.0 / (distance1 ^ j);
            distancetable(13+j) = 1.0 / (distance2 ^ j);
        end

        tmp = zeros(1,12);

        for j=1:12
            avg = 0;
            n = 0;

            for k=1:12
                weight = distancetable(j - k + 13);
                avg = avg + o(k) * weight;
                n = n + weight;
            end

            %pulse control bit
            if idx(3)
                weight = distancetable((j-1) - 12 + 13); %off by one?
                avg = avg + pulsestrength * weight;
                n = n+ weight;
            end

            tmp(j) = (o(j) + avg / n) * 0.5;
        end

        o = tmp;
    end

    o = double(o>bias);
    
    outbits(i,1,1,:) = o;
    
 end
 %out
endfunction

